==> mysql-8.0_8.0.19.orig.tar.gz: mysql-8.0.19/router/src/http/include/mysqlrouter/http_server_export.h <==
/*
  Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MYSQLROUTER_HTTP_SERVER_EXPORT_INCLUDED
#define MYSQLROUTER_HTTP_SERVER_EXPORT_INCLUDED

#ifdef _WIN32
#ifdef http_server_DEFINE_STATIC
#define HTTP_SERVER_EXPORT
#else
#ifdef http_server_EXPORTS
#define HTTP_SERVER_EXPORT __declspec(dllexport)
#else
#define HTTP_SERVER_EXPORT __declspec(dllimport)
#endif
#endif
#else
#define HTTP_SERVER_EXPORT
#endif

#endif

==> mysql-8.0_8.0.42.orig.tar.gz: mysql-8.0.42/router/src/http/include/mysqlrouter/http_server_export.h <==
/*
  Copyright (c) 2018, 2025, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MYSQLROUTER_HTTP_SERVER_EXPORT_INCLUDED
#define MYSQLROUTER_HTTP_SERVER_EXPORT_INCLUDED

#ifdef _WIN32
#ifdef http_server_DEFINE_STATIC
#define HTTP_SERVER_EXPORT
#else
#ifdef http_server_EXPORTS
#define HTTP_SERVER_EXPORT __declspec(dllexport)
#else
#define HTTP_SERVER_EXPORT __declspec(dllimport)
#endif
#endif
#else
#define HTTP_SERVER_EXPORT
#endif

#endif
